/*
* Author: Harar Zafrir zafrir@hpe.com
* Maintainer: Vlad Moldovan, moldovan@hpe.com
*
* Version: 4.2
*
* Last update: 2016-DEC-01
*
* This script creates an "OO-certified" databse in MS-SQL
* Verified on Microsoft SQL Server 2008R2, 2012 and 2014
*
* Usage:
* ------
* 1. Edit this script parameters below and set @DBNAME, @LOGIN and @PASSWD
*    to match your environment
*
* 2. Set the correct collation
*    The database is created with the "SQL_Latin1_General_CP1_CS_AS" collation by default
*    Comment / uncomment "SET @CLTION" below to select another OO-supported collation
*
* 3. Connect to the database server as "sa" (or other login with equivalent privileges)
*    and execute this script
*
* Parameters:
* -----------------------------------------------------------------------------
*
* @DBNAME:
*       The name of the created database - PLEASE EDIT!
*
* @LOGIN:
*       A dedicated login created for this database specifically - PLEASE EDIT!
*
* @PASSWD:
*       A password for the dedicated created @LOGIN - PLEASE EDIT!
*
*       NOTE! This password may be subjected to complexity / strength rules
*             implied and inherited by the domain policy.
*             Please use a complex password.
*
* @CLTION:
*       The database collation. Use the default unless you wish to use French, Japanese or Chinese.
*
* Return Values:
* -----------------------------------------------------------------------------
* None
*
* -----------------------------------------------------------------------------
* Change List
* -----------------------------------------------------------------------------
* 2016-MAR-03 [1.0] First version
* 2016-MAY-16 [4.0] No changes, maintenance package version alignment
* 2016-AUG-09 [4.1] HPE OO 10.70 adaptations
* 2016-DEC-01 [4.2] DB Maintenance Package alignment - no changes
* -----------------------------------------------------------------------------
*/

USE [master]
GO

DECLARE
@DBNAME VARCHAR(50),
@LOGIN VARCHAR(50),
@PASSWD VARCHAR(50),
@CLTION VARCHAR(100),
@qry VARCHAR(4000),
@BigQry VARCHAR(5000)

SET @DBNAME = 'myOODB';
SET @LOGIN = 'myOODBLogin';
SET @PASSWD = 'my00DBComplexPa5sword';
SET @CLTION = 'SQL_Latin1_General_CP1_CS_AS';
-- SET @CLTION = 'Japanese_Unicode_CS_AS';
-- SET @CLTION = 'Chinese_Simplified_Stroke_Order_100_CS_AS';
-- SET @CLTION = 'French_100_CS_AS';

BEGIN

	SET @qry = 'USE [master]';
	EXEC (@qry);

	SET @qry = 'CREATE DATABASE [' + @DBNAME + '] COLLATE ' + @CLTION;
	EXEC (@qry);
	SET @qry = 'ALTER DATABASE [' + @DBNAME + '] SET ALLOW_SNAPSHOT_ISOLATION ON';
	EXEC (@qry);
	SET @qry = 'ALTER DATABASE [' + @DBNAME + '] SET READ_COMMITTED_SNAPSHOT ON';
	EXEC (@qry);
	SET @qry = 'ALTER DATABASE [' + @DBNAME + '] SET AUTO_CREATE_STATISTICS ON';
	EXEC (@qry);
	SET @qry = 'ALTER DATABASE [' + @DBNAME + '] SET AUTO_SHRINK OFF';
	EXEC (@qry);

	SET @qry = 'CREATE LOGIN [' + @LOGIN + '] WITH PASSWORD=N''' + @PASSWD + ''', DEFAULT_DATABASE=[' + @DBNAME + ']';
	EXEC (@qry);

	SET @qry = 'CREATE USER ' + @LOGIN + ' FOR LOGIN [' + @LOGIN + ']';
	SET @BigQry = 'USE ' + @DBNAME + '; EXEC sp_executesql N''' + @qry + '''';
	EXEC (@BigQry);

	SET @qry = 'EXEC sp_addrolemember [db_owner], [' + @LOGIN + ']';
	SET @BigQry = 'USE ' + @DBNAME + '; EXEC sp_executesql N''' + @qry + '''';
	EXEC (@BigQry);

END;
GO
