/*
* Author: Harar Zafrir zafrir@hpe.com
* Maintainer: Vlad Moldovan, moldovan@hpe.com
*
* Version: 4.2
*
* Last update: 2016-DEC-01
*
* This script serves as an example for executing index maintenance stored procedure
* See Database Maintenance document for detailed description
* of the parameters and functionality of the stored procedure
* Verified on Microsoft SQL Server 2008R2, 2012 and 2014.
*
* Usage:
* ------
* Execute mssql_grant_view_server_state.sql in order to grant
*   "VIEW SERVER STATE" privelege to HPE OO login role
* Edit this script and replace *ALL OCCURANCES* of "<your_db_name_here>"
* with the actual name of HPE OO database
* Set parameter values according to the explanation in HPE OO's Database Guide
* Connect to the database server using HPE OO login role and execute it
*
* -----------------------------------------------------------------------------
* Change List
* -----------------------------------------------------------------------------
* 2016-MAR-03 [1.0] First version
* 2016-MAY-16 [4.0] No changes, maintenance package version alignment
* 2016-AUG-09 [4.1] HPE OO 10.70 adaptations
* 2016-DEC-01 [4.2] DB Maintenance Package alignment - no changes
* -----------------------------------------------------------------------------
*/

USE <your_db_name_here>
GO

DECLARE
@DBNAME NVARCHAR(255),
@IDXFLTR NVARCHAR(270);
SET @DBNAME = N'<your_db_name_here>';
SET @IDXFLTR = '''' + @DBNAME + '.dbo.%''';

EXECUTE [dbo].[OOIndexMaintenance]
  @DatabaseName = @DBNAME
  ,@FragmentationLow = NULL
  ,@FragmentationMedium = 'INDEX_REORGANIZE,INDEX_REBUILD_ONLINE,INDEX_REBUILD_OFFLINE'
  ,@FragmentationHigh = 'INDEX_REBUILD_ONLINE,INDEX_REBUILD_OFFLINE'
  ,@FragmentationLevel1 = 5
  ,@FragmentationLevel2 = 30
  ,@SortInTempdb = 'N'
  ,@Indexes = @IDXFLTR
  ,@TimeLimit = 1800
  ,@LockTimeout = 20
  ,@LogToTable = 'N'
  ,@Execute = 'Y'
GO
